from sphinx import addnodes
from docutils.nodes import inline
from docutils.parsers.rst.roles import set_classes
from docutils.parsers.rst import Directive


def btn_primary_role( 
	role, rawtext, text, lineno, inliner, 
	options = {}, content = [] 
):
	"""

	"""
	options.update( { 'classes': [] } )
	options[ 'classes' ].append( 'btn' )
	options[ 'classes' ].append( 'btn-sm' )
	options[ 'classes' ].append( 'btn-primary' )
	set_classes( options )

	options[ 'text' ] = text

	node = inline( **options )

	return [ node ], []



def btn_success_role(	
	role, rawtext, text, lineno, inliner, 
	options = {}, content = [] 
):
	"""

	"""
	options.update( { 'classes': [] } )
	options[ 'classes' ].append( 'btn' )
	options[ 'classes' ].append( 'btn-sm' )
	options[ 'classes' ].append( 'btn-success' )
	set_classes( options )

	options[ 'text' ] = text


	node = inline( **options )

	return [ node ], []


class BtnPrimary( Directive ):

	has_content = True

	def run( self ):
		options= {'classes' : []}
		options[ 'classes' ].append( 'btn' )
		options[ 'classes' ].append( 'btn-sm' )
		options[ 'classes' ].append( 'btn-primary' )
		set_classes( options )

		node = inline( **options )
		return [ node ]


class BtnSuccess( Directive ):

	has_content = True

	def run( self ):
		options= {'classes' : []}
		options[ 'classes' ].append( 'btn' )
		options[ 'classes' ].append( 'btn-sm' )
		options[ 'classes' ].append( 'btn-primary' )
		set_classes( options )

		node = inline( **options )
		return [ node ]


prolog = '.. |bs_btn_primary| bs_btn_primary:: bs_btn_primary\n'
prolog = '.. |bs_btn_success| bs_btn_success:: bs_btn_success\n'



def setup( app ):
	"""
	
	"""

	app.add_role( 		'bs_btn_primary', btn_primary_role )
	app.add_directive( 	'bs_btn_primary', BtnPrimary )
	
	app.add_role( 		'bs_btn_success', btn_success_role )
	app.add_directive( 	'bs_btn_success', BtnSuccess )

	app.config.rst_prolog = prolog
	return { 'version': '0.0.1' }


import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()


project_urls = {
    'Source Code':      'https://github.com/bicarlsen/sphinx-bootstrap',
    'Bug Tracker':      'https://github.com/bicarlsen/sphinx-bootstrap/issues'
}


setuptools.setup(
    name = "bric-sphinx-bootstrap",
    version = "0.0.4",
    author = "Brian Carlsen",
    author_email = "carlsen.bri@gmail.com",
    description = "Sphinx roles for Bootstrap elelments.",
    long_description = long_description,
    long_description_content_type = "text/x-rst",
    keywords = [ 'sphinx', 'rst', 'restructured text', 'bootstrap' ],
    url = "",
    project_urls = project_urls,
    packages = setuptools.find_packages(),
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha"
    ],
    install_requires = [ 'docutils', 'Sphinx' ]
)